Module: Haml

Defined in:
lib/template-inheritance/exts/haml.rb

Overview

Option default_attributes

A hash of default attributes for tags ({tag => {attribute => default_value}}). Attributes of each tag will reverse merged with his default attributes, so you don't have to write over and over that script tag has attribute type with value text/javascript. For example, %script compiles to <script type="text/javascript"></script>. Defaults to {script: {type: "text/javascript"}, form: {method: "POST"}}

Defined Under Namespace

Modules: Precompiler Classes: Buffer